@@ -1,10 +1,9 @@
-/* jshint qunit: true */
-/* global JSZip,JSZipTestUtils */
+/* global QUnit,JSZip,JSZipTestUtils */
 'use strict';
 
 QUnit.module("forEach");
 
-test("forEach works on /", function (assert) {
+QUnit.test("forEach works on /", function (assert) {
     var zip = JSZipTestUtils.createZipAll();
     var count = 0;
     var calls = [];
@@ -17,11 +16,11 @@ test("forEach works on /", function (assert) {
         calls.push(path);
     });
 
-    equal(count, 3, "the callback has been called the right number of times");
+    assert.equal(count, 3, "the callback has been called the right number of times");
     assert.deepEqual(calls, ["Hello.txt", "images/", "images/smile.gif"], "all paths have been called");
 });
 
-test("forEach works on a sub folder", function (assert) {
+QUnit.test("forEach works on a sub folder", function (assert) {
     var zip = new JSZip();
     var sub = zip.folder("subfolder");
     sub.file("Hello.txt", "Hello World\n");
@@ -38,6 +37,6 @@ test("forEach works on a sub folder", function (assert) {
         calls.push(path);
     });
 
-    equal(count, 3, "the callback has been called the right number of times");
+    assert.equal(count, 3, "the callback has been called the right number of times");
     assert.deepEqual(calls, ["Hello.txt", "images/", "images/smile.gif"], "all paths have been called");
 });
